@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.010_000;
 
-our $VERSION = '2.044000';
+our $VERSION = '2.044001';
 use App::Netdisco::Configuration;
 
 =head1 NAME
@@ -219,11 +219,11 @@ port control, etc):
 
 After installing Netdisco for the first time, you must manually discover at
 least one device on your network.  Choose a device which speaks CDP, FDP, or
-LLDP and thus knows about its neighbors; Netdisco will then start following
-this chain of neighbors to discover the rest of your network.
+LLDP and knows about its neighbors; Netdisco will then start following this
+chain of neighbors to discover the rest of your network.
 
-To do this, either go to the web interface and enter an IP or fully qualified
-domain name, or perform the following step at the command line:
+Either go to the web interface and enter an IP or fully qualified domain name,
+OR perform the following step at the command line:
 
  ~/bin/netdisco-do discover {name or IP address of a switch or router}
 
@@ -242,20 +242,7 @@ L<Release Notes|https://github.com/netdisco/netdisco/wiki/Release-Notes>.
 
 =head1 Upgrading from 2.x
 
-I<note:> Whenever you upgrade your operating system, you should delete the
-C<~/perl5> directory and re-run the C<curl> command above, to update
-Netdisco's C library bindings.
-
-I<also note:> You should take care not to run C<< netdisco-backend >> and the
-Netdisco 1.x daemon at the same time. Similarly, if you use the device
-discovery with Netdisco 2, disable your system's cron jobs for the Netdisco
-1.x poller.
-
-If you're running a version of Netdisco prior to 2.x then you should follow
-the full installation instructions, above. This process is for upgrading
-version 2.x only.
-
-Before upgrading always review the latest L<Release Notes|https://github.com/netdisco/netdisco/wiki/Release-Notes>.
+Always review the latest L<Release Notes|https://github.com/netdisco/netdisco/wiki/Release-Notes>.
 Then the process below should be run for each installation:
 
  # upgrade Netdisco
@@ -271,6 +258,12 @@ Then the process below should be run for each installation:
  # restart the backend workers (wherever you run them)
  ~/bin/netdisco-backend restart
 
+Furthermore, whenever you upgrade your Operating System, you must delete the
+C<~/perl5> directory and re-run the following command, to update Netdisco's C
+library bindings:
+
+ curl -L https://cpanmin.us/ | perl - --notest --local-lib ~/perl5 App::Netdisco
+
 =head1 Tips and Tricks
 
 =head2 Searching
