@@ -16,9 +16,6 @@ register_worker({ phase => 'check' }, sub {
   return Status->error("arpnip skipped: $device not yet discovered")
     unless $device->in_storage;
 
-  return Status->info("arpnip skipped: $device has no layer 3 capability")
-    unless $device->has_layer(3);
-
   return Status->info("arpnip skipped: $device is not arpnipable")
     unless is_arpnipable_now($device);
 
